summaryrefslogtreecommitdiffstats
path: root/keduca/keduca/kcheckeduca.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'keduca/keduca/kcheckeduca.cpp')
-rw-r--r--keduca/keduca/kcheckeduca.cpp24
1 files changed, 12 insertions, 12 deletions
diff --git a/keduca/keduca/kcheckeduca.cpp b/keduca/keduca/kcheckeduca.cpp
index 8fe6b557..a75c8478 100644
--- a/keduca/keduca/kcheckeduca.cpp
+++ b/keduca/keduca/kcheckeduca.cpp
@@ -18,10 +18,10 @@
#include "kcheckeduca.h"
#include "kcheckeduca.moc"
-#include <qstyle.h>
+#include <tqstyle.h>
#include <kaccelmanager.h>
-KCheckEduca::KCheckEduca(QWidget *parent, const char *name ) : QCheckBox(parent,name)
+KCheckEduca::KCheckEduca(TQWidget *parent, const char *name ) : TQCheckBox(parent,name)
{
_doc = 0;
KAcceleratorManager::setNoAccel( this );
@@ -33,21 +33,21 @@ KCheckEduca::~KCheckEduca()
}
/** */
-void KCheckEduca::drawButtonLabel( QPainter *p){
+void KCheckEduca::drawButtonLabel( TQPainter *p){
int x, y, w, h;
int extra_width, indicator_width;
extra_width = 8;
- indicator_width = style().pixelMetric(QStyle::PM_IndicatorWidth, 0);
+ indicator_width = style().pixelMetric(TQStyle::PM_IndicatorWidth, 0);
y = 0;
x = indicator_width + extra_width; //###
w = width() - x;
h = height();
- QRect cr(x,y,w,h);
+ TQRect cr(x,y,w,h);
- _doc = new QSimpleRichText( text(), font() );
+ _doc = new TQSimpleRichText( text(), font() );
_doc->setWidth( 10 );
_doc->setWidth(p, cr.width() );
@@ -61,25 +61,25 @@ void KCheckEduca::drawButtonLabel( QPainter *p){
yo = (cr.height()-rh)/2;
if ( !isEnabled() ) {
- QColorGroup cg = colorGroup();
- cg.setColor( QColorGroup::Text, cg.light() );
+ TQColorGroup cg = colorGroup();
+ cg.setColor( TQColorGroup::Text, cg.light() );
_doc->draw(p, cr.x()+xo+1, cr.y()+yo+1, cr, cg, 0);
}
_doc->draw(p, cr.x()+xo, cr.y()+yo, cr, colorGroup(), 0);
if ( hasFocus() ) {
// QRect br = style().itemRect( p, x, y, rw, rh+yo,
// AlignLeft|AlignVCenter|ShowPrefix,
// isEnabled(),
// pixmap(), text().visual() );
- QRect br(x,y,rw,rh+yo);
+ TQRect br(x,y,rw,rh+yo);
br.setLeft( br.left()-3 );
br.setRight( br.right()+2 );
br.setTop( br.top()-2 );
br.setBottom( br.bottom()+2);
- br = br.intersect( QRect(0,0,rw, rh+yo ) );
+ br = br.intersect( TQRect(0,0,rw, rh+yo ) );
- style().drawPrimitive( QStyle::PE_FocusRect, p, br, colorGroup());
+ style().drawPrimitive( TQStyle::PE_FocusRect, p, br, colorGroup());
}
}
@@ -61,25 +61,25 @@ void KCheckEduca::drawButtonLabel( QPainter *p){
_doc->draw(p, cr.x()+xo, cr.y()+yo, cr, colorGroup(), 0);
if ( hasFocus() ) {
-// QRect br = style().itemRect( p, x, y, rw, rh+yo,
+// TQRect br = style().itemRect( p, x, y, rw, rh+yo,
// AlignLeft|AlignVCenter|ShowPrefix,
// isEnabled(),